CLI Tools
=========

.. toctree::
   :titlesonly:

   baseplate-healthcheck: Check if your service is alive <healthcheck>
   baseplate-serve: The application server <serve>
   baseplate-script: Run backend scripts <script>
   baseplate-shell: Begin an interactive shell for a service <shell>
